@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.019-17-g76b4058
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.020-5-g167d1d4
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 
-our $VERSION = '0.020'; # TRIAL
+our $VERSION = '0.021'; # TRIAL
 
 use Moose;
 with
@@ -144,26 +144,29 @@ sub munge_files
 
     $self->log_debug('Inserting dynamic prereq into Makefile.PL...');
 
+    # we insert our code just *before* this bit in Makefile.PL
+    my $insertion_breadcrumb = "\n\nunless ( eval { ExtUtils::MakeMaker";
+
     # insert after declarations for BOTH %WriteMakefileArgs, %FallbackPrereqs.
     # TODO: if marker cannot be found, fall back to looking for just
     # %WriteMakefileArgs -- this requires modifying the content too.
     $self->log_fatal('failed to find position in Makefile.PL to munge!')
-        if $content !~ m/^my \{\{ \$fallback_prereqs \}\}$/mg;
+        if $content !~ m/\Q$insertion_breadcrumb/mg;
 
-    my $pos = pos($content);
+    my $pos = pos($content) - length($insertion_breadcrumb);
 
     my $code = join("\n", $self->raw);
     if (my $conditions = join(' && ', $self->conditions))
     {
         $code = "if ($conditions) {\n"
             . $code . "\n"
-            . '}';
+            . '}' . "\n";
     }
 
     $content = substr($content, 0, $pos)
-        . "\n\n"
+        . "\n"
         . $self->_header . "\n"
-        . $code
+        . $code . "\n"
         . substr($content, $pos);
 
     $content =~ s/\n+\z/\n/;
@@ -179,7 +182,7 @@ has _header => (
     lazy => 1,
     default => sub {
         my $self = shift;
-        "# inserted by " . blessed($self) . ' ' . $self->VERSION;
+        '# inserted by ' . blessed($self) . ' ' . $self->VERSION;
     },
 );
 
@@ -349,7 +352,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
